summaryrefslogtreecommitdiff
path: root/lib/charnames.pm
diff options
context:
space:
mode:
authorKarl Williamson <public@khwilliamson.com>2011-10-04 11:58:52 -0600
committerKarl Williamson <public@khwilliamson.com>2011-11-08 08:09:23 -0700
commita03f0b9fc88f383466124c0fba3dd41d5c76b99e (patch)
treebb0f404111ec063e444083876337455c7cee001a /lib/charnames.pm
parent6f424f62d78f1d774afc307a13f39aec87bfac16 (diff)
downloadperl-a03f0b9fc88f383466124c0fba3dd41d5c76b99e.tar.gz
Use newly created Name.pm file
Name.pm has been populated in an earlier commit. This removes the now redundant information in Name.pl, and changes charnames to include the new Name.pm
Diffstat (limited to 'lib/charnames.pm')
-rw-r--r--lib/charnames.pm9
1 files changed, 5 insertions, 4 deletions
diff --git a/lib/charnames.pm b/lib/charnames.pm
index f3894f1870..d88ede0e59 100644
--- a/lib/charnames.pm
+++ b/lib/charnames.pm
@@ -2,7 +2,8 @@ package charnames;
use strict;
use warnings;
use File::Spec;
-our $VERSION = '1.23';
+our $VERSION = '1.24';
+use unicore::Name; # mktables-generated algorithmically-defined names
use bytes (); # for $bytes::hint_bits
@@ -12,9 +13,9 @@ use bytes (); # for $bytes::hint_bits
# lib/unicore/Name.pl which is read in as a large string (almost 3/4 Mb in
# Unicode 6.0). Each code point/name combination is separated by a \n in the
# string. (Some of the CJK and the Hangul syllable names are determined
# instead algorithmically via subroutines also stored in Name.pl). Because of
# the large size of this table, it isn't converted into hashes for faster
# lookup.
#
# But, user defined aliases are stored in their own hashes, as are Perl
# extensions to the official names. These are checked first before looking at
@@ -12,9 +13,9 @@ use bytes (); # for $bytes::hint_bits
# Unicode 6.0). Each code point/name combination is separated by a \n in the
# string. (Some of the CJK and the Hangul syllable names are determined
-# instead algorithmically via subroutines also stored in Name.pl). Because of
-# the large size of this table, it isn't converted into hashes for faster
-# lookup.
+# instead algorithmically via subroutines stored instead in
+# lib/unicore/Name.pm). Because of the large size of this table, it isn't
+# converted into hashes for faster lookup.
#
# But, user defined aliases are stored in their own hashes, as are Perl